package VMOMI::FtIssuesOnHostHostSelectionType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
